##  Step 4: Create an Access Key
Create an access key for the user to allow access to Amazon Bedrock.
Follow these steps:
  1. In the AWS console, go to the Identity and Access Management (IAM) section.
  2. Go to the Users section, then find the user you created and select it.
  3. On the user details page, go to the Security credentials tab, then choose Create access key.
![AWS IAM user Security credentials tab showing options to create an access key.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio351736c00e1b457d8f8ff794a2d674be_LowRes.png)
Creating an Access Key
  4. On the Access key best practices & alternatives page, choose Other, then choose Next.
![AWS IAM page showing access key use case options with "Other" selected.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio46c327e4cfa74b278c1dba6dd98a6c9c_LowRes.png)
Choosing "Other" from the Use Cases List
  5. Enter a tag for the key, then choose Create access key.
![AWS IAM page for setting an optional description tag for a new access key.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio1ef47e4ed0c44088a4df93f78adab841_LowRes.png)
Adding a Tag and Confirming the Creation of an Access Key
  6. Save the access and secret access keys securely. The secret access key is shown only once. You cannot recover it. If you lose your secret access key or want to rotate keys, create a new one.
